'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompletionTrigger = void 0;
/**
 * Defines a trigger that signifies page render completion.
 *
 * @export
 * @abstract
 * @class CompletionTrigger
 */
class CompletionTrigger {
    /**
     * Creates an instance of CompletionTrigger.
     * @param {number} [timeout=1000] milliseconds until timing out.
     * @param {string} [timeoutMessage='CompletionTrigger timed out.'] The timeout message.
     * @memberof CompletionTrigger
     */
    constructor(timeout = 1000, timeoutMessage = 'CompletionTrigger timed out.') {
        this.timeout = timeout;
        this.timeoutMessage = timeoutMessage;
    }
    /**
     * Optional hook to initialize the CompletionTrigger before navigation.
     * @param {CDP.Client} _client the Chrome connection information.
     * @returns {Promise<void>} resolves if initialized, rejects on error.
     * @memberof CompletionTrigger
     */
    init(_client) {
        return Promise.resolve();
    }
}
exports.CompletionTrigger = CompletionTrigger;
//# sourceMappingURL=CompletionTrigger.js.map